@@ -652,7 +652,7 @@ class IikoServer:
 
         """
         try:
-            urls = self.address + '/resto/api/v2/reports/olap?key=' + self._token
+            urls = self.address + 'resto/api/v2/reports/olap?key=' + self._token
             return requests.get(
                 urls,
                 params={groupingAllowed, filteringAllowed},
@@ -877,4 +877,4 @@ class IikoServer:
                 urls, params=payload, timeout=DEFAULT_TIMEOUT).content
 
         except Exception as e:
-            print(e)
+            print(e)
\ No newline at end of file
